@@ -1,4 +1,5 @@
 import io
+from typing import Union, List
 
 import sys
 
@@ -34,20 +35,27 @@ class DrbXQuery:
         # parse query and reject it if error
         self.tree = self.parser.module()
 
-    def execute(self, node: DrbNode, external_var: dict = None):
+    def execute(self, *args, **kwargs):
 
         old_limit = sys.getrecursionlimit()
         sys.setrecursionlimit(10000)
 
-        # Execute the query on the node
-        visitor = DrbQueryVisitor(DynamicContext(node), tokens=self.stream)
-        visitor.external_var_map = external_var
-        self.static_context = visitor.static_context
+        list_nodes = args
 
-        output = visitor.visitModule(self.tree)
-        if not isinstance(output, list):
-            output = [output]
+        output_list = []
+        for node_item in list_nodes:
+            visitor = DrbQueryVisitor(DynamicContext(node_item),
+                                      tokens=self.stream)
+
+            visitor.external_var_map = kwargs
+            self.static_context = visitor.static_context
+
+            output = visitor.visitModule(self.tree)
+            if not isinstance(output, list):
+                output_list.append(output)
+            else:
+                output_list.extend(output)
 
         sys.setrecursionlimit(old_limit)
 
-        return output
+        return output_list
