@@ -21,9 +21,17 @@ class XqueryVariable:
         self.name = name
         self.external = external
         self.value = value
+        self.arg_min = 1
+        self.arg_max = 0
         if type_var is not None:
+            if isinstance(type_var, tuple):
+                self.arg_min = type_var[1]
+                self.arg_max = type_var[2]
+                type_var_full = type_var[0]
+            else:
+                type_var_full = type_var
             self.type_var_namespace, self.type_var = \
-                DrbQueryFuncUtil.split_namespace_name(type_var)
+                DrbQueryFuncUtil.split_namespace_name(type_var_full)
         else:
             self.type_var_namespace, self.type_var = (None, None)
         self._typed_value = None
@@ -32,7 +40,9 @@ class XqueryVariable:
         if self._typed_value is None:
             self._typed_value = self.get_value_typed(self.type_var,
                                                      self.type_var_namespace,
-                                                     self.value)
+                                                     self.value,
+                                                     arg_min=self.arg_min,
+                                                     arg_max=self.arg_max)
         return self._typed_value
 
     @staticmethod
