@@ -9,6 +9,7 @@ from antlr4.tree.Tree import TerminalNodeImpl
 
 from drb import DrbNode
 from drb.factory import DrbFactoryResolver
+from drb_impl_xml import XmlNode
 
 from .XQueryLexer import XQueryLexer
 from .XQueryParser import XQueryParser
@@ -61,7 +62,10 @@ class DrbQueryVisitor(XQueryParserVisitor):
     def get_namespace_full_name(self, prefix: str):
         ns_full = self.static_context.get_namespace_full_name(prefix)
         if self.dynamic_context and len(ns_full) == 0:
-            ns_full = self.dynamic_context.get_namespace_full_name(prefix)
+            if isinstance(self.dynamic_context, DynamicContext):
+                ns_full = self.dynamic_context.get_namespace_full_name(prefix)
+            else:
+                return ns_full
         return ns_full
 
     def visitVersionDecl(self, ctx: XQueryParser.VersionDeclContext):
@@ -708,10 +712,9 @@ class DrbQueryVisitor(XQueryParserVisitor):
             test = ctx.getText().split(':')
 
             prefix_namespace = test[0]
-            self.current_axe.namespace = self.get_namespace_full_name(
-                prefix_namespace)
-            if len(self.current_axe.namespace) == 0:
-                self.current_axe.namespace = prefix_namespace
+            self.current_axe.set_namespace_full(
+                self.get_namespace_full_name(
+                    prefix_namespace), prefix_namespace)
             self.current_axe.name = test[1]
 
             return ctx.getText()
@@ -1139,6 +1142,18 @@ class DrbQueryVisitor(XQueryParserVisitor):
         raise NotImplementedError(
             'Unsupported Axis operator :' + ctx.getText())
 
+    @staticmethod
+    def get_attributes_node(node, name, namespace, list_result):
+        try:
+            value_attr = node.get_attribute(
+                name,
+                namespace)
+
+            return value_attr
+        except Exception as Error:
+            pass
+        return None
+
     @staticmethod
     def get_attributes(node, current_axe, list_result):
         if current_axe.is_wildcard:
@@ -1149,44 +1164,63 @@ class DrbQueryVisitor(XQueryParserVisitor):
                                    attribute=True,
                                    position=len(list_result) + 1))
         else:
-            try:
-                value_attr = node.get_attribute(
-                    current_axe.name,
-                    current_axe.namespace)
-                if value_attr is not None:
-                    list_result.append(DynamicContext(
-                        (current_axe.name,
-                         current_axe.namespace),
-                        value=value_attr, parent=node,
-                        attribute=True,
-                        position=len(list_result) + 1))
-            except Exception as Error:
-                # no   attribute with this name.
-                pass
+            name_attribute = current_axe.name
+            namespace_attribute = current_axe.namespace
+            value_attr = DrbQueryVisitor.get_attributes_node(
+                node,
+                name_attribute,
+                namespace_attribute,
+                list_result)
+            if value_attr is None and namespace_attribute is not None and \
+                    not current_axe.namespace_resolved and \
+                    not isinstance(node, XmlNode):
+                name_attribute = namespace_attribute + ':' + name_attribute
+                namespace_attribute = None
+                value_attr = DrbQueryVisitor.get_attributes_node(
+                    node,
+                    name_attribute,
+                    namespace_attribute,
+                    list_result)
+
+            if value_attr is not None:
+                list_result.append(DynamicContext(
+                    (name_attribute, namespace_attribute),
+                    value=value_attr, parent=node,
+                    attribute=True,
+                    position=len(list_result) + 1))
+
         return list_result
 
+    @staticmethod
+    def get_children_node(node, name, namespace):
+        try:
+            if node.has_child(name, namespace):
+                if isinstance(node, DrbXqueryItem):
+                    return node.get_named_child_list(name, namespace)
+                else:
+
+                    return node[name, namespace, :]
+        except Exception:
+            pass
+        return []
+
     @staticmethod
     def get_children(node, current_axe, list_result):
         next_nodes = []
         if current_axe.is_wildcard:
             next_nodes = node.children
-        elif node.has_child(current_axe.name,
-                            current_axe.namespace):
-            if isinstance(node, DrbXqueryItem):
-                next_nodes = node.get_named_child_list(current_axe.name,
-                                                       current_axe.namespace)
-            else:
-
-                next_nodes = node[current_axe.name,
-                                  current_axe.namespace, :]
-        # elif node.has_child(current_axe.name,
-        #                     None):
-        #     if isinstance(node, DrbXqueryItem):
-        #         next_nodes = node.get_named_child_list(current_axe.name,
-        #                                                None)
-        #     else:
-        #         next_nodes = node[current_axe.name,
-        #                      None, :]
+        else:
+            next_nodes = DrbQueryVisitor.get_children_node(
+                node,
+                current_axe.name,
+                current_axe.namespace)
+            if len(next_nodes) == 0 and \
+                    current_axe.namespace is not None and \
+                    not current_axe.namespace_resolved and \
+                    not isinstance(node, XmlNode):
+                child_name = current_axe.namespace + ':' + current_axe.name
+                next_nodes = DrbQueryVisitor.get_children_node(
+                    node, child_name, None)
         for node_drb in next_nodes:
             list_result.append(DynamicContext(
                 node_drb,
@@ -1299,6 +1333,8 @@ class DrbQueryVisitor(XQueryParserVisitor):
                 result = []
                 index = 0
                 for node in self.list_context:
+                    if not isinstance(node, DynamicContext):
+                        node = DynamicContext(node=node)
 
                     visitor_exp = DrbQueryVisitor(
                         node, step_nav=step_nav,
