@@ -2,6 +2,7 @@ import os
 import unittest
 from pathlib import Path
 
+from drb.utils.logical_node import DrbLogicalNode
 from drb_impl_file import DrbFileFactory
 from drb_impl_xml import XmlNodeFactory
 from drb_xquery.drb_xquery import DrbXQuery
@@ -204,7 +205,7 @@ class TestDrbXQueryFunc(unittest.TestCase):
             "/Level-2A_Tile_ID/Test_FLF[not('0')]")
         node_result = query.execute(self.node)
 
-        self.assertEqual(len(node_result), 6)
+        self.assertEqual(len(node_result), 0)
 
         query = DrbXQuery(
             "/Level-2A_Tile_ID/Test_FLF[not(elt)]")
@@ -291,6 +292,14 @@ class TestDrbXQueryFunc(unittest.TestCase):
         self.node_file = DrbFileFactory().create(self.xml_file)
         self.node = XmlNodeFactory().create(self.node_file)
 
+        query = DrbXQuery('substring("a", 1, 1)')
+        node_result = query.execute(None)
+        self.assertListEqual(node_result, ['a'])
+
+        query = DrbXQuery('substring("abcdef", 2)')
+        node_result = query.execute(None)
+        self.assertListEqual(node_result, ['bcdef'])
+
         query = DrbXQuery(
             "/Level-2A_Tile_ID/Test_FLF[substring(elt, 6, 2) = 'is']")
         node_result = query.execute(self.node)
@@ -670,3 +679,100 @@ class TestDrbXQueryFunc(unittest.TestCase):
         node_result = query.execute(None)
 
         self.assertListEqual(node_result, [6])
+
+    def test_xquery_func_text(self):
+        self.node_file = DrbFileFactory().create(self.xml_file)
+        self.node = XmlNodeFactory().create(self.node_file)
+
+        query = DrbXQuery("/Level-2A_Tile_ID/Test_FLF/name/text()")
+        node_result = query.execute(self.node)
+
+        self.assertEqual(len(node_result), 6)
+        self.assertIn('first', node_result)
+        self.assertIn('second', node_result)
+
+    def test_xquery_func_text_empty(self):
+        self.node_file = DrbFileFactory().create(self.xml_file)
+        self.node = XmlNodeFactory().create(self.node_file)
+
+        query = DrbXQuery("/Level-2A_Tile_ID/Test_FLF/text()")
+        node_result = query.execute(self.node)
+
+        self.assertListEqual(node_result, [])
+
+    def test_xquery_func_text_KO(self):
+        child = DrbLogicalNode('child')
+        child.add_attribute('attr', 42)
+        child.value = 'test'
+        node = DrbLogicalNode('foobar')
+        node.append_child(child)
+
+        query = DrbXQuery("/child/@attr/text()")
+        node_result = query.execute(node)
+
+        self.assertListEqual(node_result, [])
+
+    def test_xquery_func_text_OK(self):
+        child = DrbLogicalNode('child')
+        child.add_attribute('attr', '42')
+        child.value = 'test_child'
+        node = DrbLogicalNode('foobar')
+        node.append_child(child)
+
+        query = DrbXQuery("/child/@attr/text()")
+        node_result = query.execute(node)
+
+        self.assertListEqual(node_result, ['42'])
+
+        query = DrbXQuery("/child/text()")
+        node_result = query.execute(node)
+
+        self.assertListEqual(node_result, ['test_child'])
+
+    def test_xquery_func_text_in_predicate(self):
+        child = DrbLogicalNode('child')
+        child.add_attribute('attr', '42')
+        child.value = 42
+        node = DrbLogicalNode('foobar')
+        node.append_child(child)
+
+        child2 = DrbLogicalNode('child')
+        child.value = 'child_text'
+        node = DrbLogicalNode('foobar')
+        node.append_child(child)
+        node.append_child(child2)
+
+        query = DrbXQuery("/child[text()]")
+        node_result = query.execute(node)
+
+        self.assertEqual(node_result[0].value, 'child_text')
+
+    def test_xquery_func_complex(self):
+        self.node_file = DrbFileFactory().create(self.xml_file)
+        self.node = XmlNodeFactory().create(self.node_file)
+
+        query = DrbXQuery("declare function local:levenshtein" +
+                          "($arg1 as xs:string, $arg2 as xs:string)" +
+                          " as xs:decimal {\n" +
+                          "if (string-length($arg1) = 0) "
+                          "then\n" +
+                          "string-length($arg2)\n" +
+                          "else if (string-length($arg2) = 0)\n" +
+                          "then string-length($arg1)\n" +
+                          "else min((local:levenshtein(substring($arg1, 2), "
+                          "$arg2) + 1,\n" +
+                          "   local:levenshtein($arg1, substring($arg2, 2)) "
+                          "+ 1,\n" +
+                          "    local:levenshtein(substring($arg1, 2),"
+                          "substring($arg2, 2)) + \n" +
+                          "    (if (substring($arg1, 1, 1) = "
+                          "substring($arg2, 1, 1)) \n" +
+                          "       then \n" +
+                          "           0\n" +
+                          "       else 1)" +
+                          "))\n" +
+                          "       };\n" +
+                          'local:levenshtein("aaa", "a a a")')
+        node_result = query.execute(None)
+
+        self.assertListEqual(node_result, [2])
